@@ -1683,11 +1683,19 @@ build_msg ( ECalBackendExchange *cbex, ECalComponent *comp, const char *subject,
 			attach_file = fname;
 		} else {
 			fname = (char *)(l->data);
-			mime_filename = g_path_get_basename (fname);
-			attach_file = g_strdup_printf ("%s/%s-%s", cbex->priv->local_attachment_store, uid, mime_filename);
+			filename = g_strrstr (fname, "/");
+			if (!filename) {
+				/*
+				 * some vcards contain e.g. ATTACH:CID:0fd601c67efb$ef66760d$_CDOEX
+				 * -> ignore instead of crashing
+				 */
+				continue;
+			}
+			mime_filename = g_strdup (filename+1);
+			attach_file = g_strdup_printf ("%s/%s-%s", cbex->priv->local_attachment_store, uid, filename);
 		}
 		/* mime_filename and attach_file should be g_freed */
-	
+
 		file_contents = get_attach_file_contents (fname, &len);
 		if (!file_contents){
 			g_free (attach_file);
